#!/bin/bash
#
# Creates both the binary distribution (.dmg) and the source distribution
# (.tar.gz) of dgsmonX.

MYNAME="$(basename "$0")"
PROJECT_DIR="$(dirname "$0")"
# Make sure that project directory is an absolute path
case "$PROJECT_DIR" in
  /*) ;;
  *)  PROJECT_DIR="$(pwd)/$PROJECT_DIR"
      ;;
esac
TMP_DIR="/tmp/$MYNAME.tmp.$$"
PROJECT_DISTDIR="$PROJECT_DIR/dist"
PROJECT_BUILDDIR="$PROJECT_DIR/build/Release"
BUNDLE_NAME="dgsmonX.app"
PROJECT_NAME=dgsmonx

if test $# -ne 1; then
  echo "No version given"
  exit 1
fi
VERSION=$1
DISTRIBUTION_NAME="$PROJECT_NAME-$VERSION"
SOURCE_DISTRIBUTION_DIR="$DISTRIBUTION_NAME"
SOURCE_DISTRIBUTION_FILE="$SOURCE_DISTRIBUTION_DIR.tar"
BIN_DISTRIBUTION_FILE="$DISTRIBUTION_NAME.dmg"

if test ! -d "$PROJECT_BUILDDIR/$BUNDLE_NAME"; then
  echo "Application bundle does not exist: $PROJECT_BUILDDIR/$BUNDLE_NAME"
  exit 1
fi

# Create directories
mkdir -p "$TMP_DIR"
if test $? -ne 0; then
  echo "error mkdir -p $TMP_DIR"
  exit 1
fi
if test ! -d "$PROJECT_DISTDIR"; then
  mkdir -p "$PROJECT_DISTDIR"
  if test $? -ne 0; then
    echo "error mkdir -p $PROJECT_DISTDIR"
    exit 1
  fi
fi

# Make the source distribution (from a clean git clone)
cd "$TMP_DIR"
git clone "$PROJECT_DIR" "$SOURCE_DISTRIBUTION_DIR"
if test $? -ne 0; then
  echo "Error git-clone $PROJECT_DIR $SOURCE_DISTRIBUTION_DIR"
  exit 1
fi
tar cf "$SOURCE_DISTRIBUTION_FILE" --exclude .git "$SOURCE_DISTRIBUTION_DIR"
if test $? -ne 0; then
  echo "Error tarring"
  exit 1
fi
gzip "$SOURCE_DISTRIBUTION_FILE"
if test $? -ne 0; then
   echo "Error gzipping"
   exit 1
fi
mv "$SOURCE_DISTRIBUTION_FILE.gz" "$PROJECT_DISTDIR"

# Make the binary distribution (from the most recent release build)
hdiutil create -ov -srcfolder "$PROJECT_BUILDDIR/$BUNDLE_NAME" -volname "$DISTRIBUTION_NAME" "$PROJECT_DISTDIR/$BIN_DISTRIBUTION_FILE"

# Cleanup
rm -rf "$TMP_DIR"
